@@ -1,22 +1,22 @@
 setClass("ltraj", representation("list"))
-setClass("STSDFtraj", representation("STSDF"),
+setClass("STIDFtraj", representation("STIDF"),
   validity = function(object) {
     if (is.null(object$burst))
 		stop("data.frame component should have a burst column")
     return(TRUE)
   }
 )
-setAs("ltraj", "STSDFtraj", 
+setAs("ltraj", "STIDFtraj", 
 	function(from) {
 		d = do.call(rbind, from)
 		n = unlist(lapply(from, nrow))
 		# take burst to fill id:
 		d$id = rep(unlist(t(sapply(from, attributes))[,4]), times = n)
 		d$burst = rep(unlist(t(sapply(from, attributes))[,5]), times = n)
-		new("STSDFtraj", STSDF(SpatialPoints(d[c("x","y")]), d$date, d))
+		new("STIDFtraj", STIDF(SpatialPoints(d[c("x","y")]), d$date, d))
 	}
 )
-setAs("STSDFtraj", "ltraj", 
+setAs("STIDFtraj", "ltraj", 
 	function(from) {
 		xy = coordinates(from@sp)
 		da = index(from@time)
@@ -24,7 +24,7 @@ setAs("STSDFtraj", "ltraj",
 	}
 )
 
-plot.STSDFtraj = function(x,y,..., byBurst = TRUE, 
+plot.STIDFtraj = function(x,y,..., byBurst = TRUE, 
 			col = "black", lty = 1, lwd = 1, 
 			type = "l", pch = 1,
 			add = FALSE) {
@@ -45,14 +45,14 @@ plot.STSDFtraj = function(x,y,..., byBurst = TRUE,
 			type = type, pch = pch)
 }
 
-setMethod("plot", signature(x = "STSDFtraj", y = "missing"), plot.STSDFtraj)
+setMethod("plot", signature(x = "STIDFtraj", y = "missing"), plot.STIDFtraj)
 
-rbind.STSDFtraj = function(...) {
+rbind.STIDFtraj = function(...) {
     dots = list(...)
     names(dots) <- NULL # bugfix Clement Calenge 100417
 	p4s = proj4string(dots[[1]]@sp)
     df = do.call("rbind", lapply(dots, function(x) as(x, "data.frame")))
 	sp = SpatialPoints(df[coordnames(dots[[1]]@sp)]) 
 	proj4string(sp) = p4s
-	new("STSDFtraj", STSDF(sp, df$time, df))
+	new("STIDFtraj", STIDF(sp, df$time, df))
 }
